@@ -1,4 +1,4 @@
-#pragma ident "@(#) $Id: iread.c,v 1.30 2007/08/02 08:36:55 bzfkocht Exp $"
+#pragma ident "@(#) $Id$"
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: iread.c                                                       */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2007 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2008 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,7 +30,12 @@
 #include <assert.h>
 #include <ctype.h>
 #include <sys/types.h>
+
+#ifdef WITH_PCRE
+#include <pcreposix.h>
+#else
 #include <regex.h>
+#endif
 
 #ifndef _lint
 #include <zlib.h>
@@ -789,12 +794,30 @@ CodeNode* i_read(CodeNode* self)
       }
       mio_close(fp);
    }
-   
+
+   /* If we found nothing to put into the list, we add a dummy entry
+    */
    if (list == NULL)
    {
-      fprintf(stderr, "*** Error 158: Read from file found no data\n");
-      code_errmsg(self);
-      zpl_exit(EXIT_FAILURE);
+      Tuple* tuple = tuple_new(0);
+
+      if (is_tuple_list)
+         list = list_new_tuple(tuple);           
+      else
+      {
+         Set* set     = set_pseudo_new();
+         Entry* entry = entry_new_set(tuple, set);
+               
+         list = list_new_entry(entry);
+         
+         entry_free(entry);
+         set_free(set);
+      }
+      tuple_free(tuple);
+
+      //fprintf(stderr, "*** Error 158: Read from file found no data\n");
+      //code_errmsg(self);
+      //zpl_exit(EXIT_FAILURE);
    }
    code_value_list(self, list);
 
