@@ -1,4 +1,4 @@
-#pragma ident "@(#) $Id: mme.h,v 1.85 2007/08/02 08:36:55 bzfkocht Exp $"
+#pragma ident "@(#) $Id$"
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: mme.h                                                         */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2007 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2008 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -204,6 +204,8 @@ extern void         numb_abs(Numb* numb);
 extern void         numb_sgn(Numb* numb);
 /*lint -sem(        numb_get_sgn, 1p == 1, @n >= -1 && @n <= 1) */
 extern int          numb_get_sgn(const Numb* numb);
+/*lint -sem(        numb_round, 1p == 1) */
+extern void         numb_round(Numb* numb);
 /*lint -sem(        numb_ceil, 1p == 1) */
 extern void         numb_ceil(Numb* numb);
 /*lint -sem(        numb_floor, 1p == 1) */
@@ -753,8 +755,8 @@ extern void         prog_add_stmt(Prog* prog, Stmt* stmt);
 extern void         prog_print(FILE* fp, const Prog* prog);
 /*lint -sem(        prog_execute, 1p == 1) */
 extern void         prog_execute(const Prog* prog);
-/*lint -sem(        prog_tostr, 1p == 1 && nulterm(2), nulterm(@)) */
-extern char*        prog_tostr(const Prog* prog, const char* prefix, const char* title);
+/*lint -sem(        prog_tostr, 1p == 1 && nulterm(2) && 3n > 0, nulterm(@)) */
+extern char*        prog_tostr(const Prog* prog, const char* prefix, const char* title, int max_output_line_len);
 
 /* load.c
  */
@@ -780,14 +782,19 @@ extern MFP*         mio_open(const char* name, const char* ext);
 extern void         mio_close(MFP* mfp);
 /*lint -function(   fgetc, mio_getc) */
 extern int          mio_getc(const MFP* mfp);
-/*lint -function(   fgets(1), mio_gets(2))) */
-/*lint -function(   fgets(2), mio_gets(3))) */
-/*lint -function(   fgets(3), mio_gets(1))) */
-/*lint -function(   fgets(r), mio_gets(r))) */
+/*lint -function(   fgets(1), mio_gets(2)) */
+/*lint -function(   fgets(2), mio_gets(3)) */
+/*lint -function(   fgets(3), mio_gets(1)) */
+/*lint -function(   fgets(r), mio_gets(r)) */
 extern char*        mio_gets(const MFP* mfp, char* buf, int len);
 /*lint -sem(        mio_get_line, 1p) */
 extern char*        mio_get_line(const MFP* mfp);
 
+/* zimpllib.c
+ */
+/*lint -sem(        zpl_print_banner, 1p == 1) */
+extern void         zpl_print_banner(FILE* fp, Bool with_license);
+
 /* vinst.c
  */
 extern void interns_init(void);
@@ -831,7 +838,7 @@ extern int          scan_get_column(void);
 #define SID_ok2(p, id)   TRUE
 #endif /* NDEBUG */
 
-#define DISPERSE(x) (1664525U * (x) + 1013904223U);
+#define DISPERSE(x) (1664525U * (x) + 1013904223U)
 
 #ifdef TRACE
 #define Trace(fname) fprintf(stderr, "Trace: %s\n", fname);
